==> libqt4pas_2.4.orig.tar.gz: splitbuild-qt4pas-V2.4_Qt4.5.3/src/qvalidator_c.cpp <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#include "qvalidator_c.h"

void QValidator_setLocale(QValidatorH handle, const QLocaleH locale)
{
	((QValidator *)handle)->setLocale(*(const QLocale*)locale);
}

void QValidator_locale(QValidatorH handle, QLocaleH retval)
{
	*(QLocale *)retval = ((QValidator *)handle)->locale();
}

QValidator::State QValidator_validate(QValidatorH handle, PWideString p1, int* p2)
{
	QString t_p1;
	copyPWideStringToQString(p1, t_p1);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QValidator *)handle)->validate(t_p1, *(int*)p2);
	copyQStringToPWideString(t_p1, p1);
	return t_retval;
}

void QValidator_fixup(QValidatorH handle, PWideString p1)
{
	QString t_p1;
	copyPWideStringToQString(p1, t_p1);
	((QValidator *)handle)->fixup(t_p1);
	copyQStringToPWideString(t_p1, p1);
}

QIntValidatorH QIntValidator_create(QObjectH parent)
{
	return (QIntValidatorH) new QIntValidator((QObject*)parent);
}

void QIntValidator_destroy(QIntValidatorH handle)
{
	delete (QIntValidator *)handle;
}

QIntValidatorH QIntValidator_create2(int bottom, int top, QObjectH parent)
{
	return (QIntValidatorH) new QIntValidator(bottom, top, (QObject*)parent);
}

QValidator::State QIntValidator_validate(QIntValidatorH handle, PWideString p1, int* p2)
{
	QString t_p1;
	copyPWideStringToQString(p1, t_p1);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QIntValidator *)handle)->validate(t_p1, *(int*)p2);
	copyQStringToPWideString(t_p1, p1);
	return t_retval;
}

void QIntValidator_setBottom(QIntValidatorH handle, int p1)
{
	((QIntValidator *)handle)->setBottom(p1);
}

void QIntValidator_setTop(QIntValidatorH handle, int p1)
{
	((QIntValidator *)handle)->setTop(p1);
}

void QIntValidator_setRange(QIntValidatorH handle, int bottom, int top)
{
	((QIntValidator *)handle)->setRange(bottom, top);
}

int QIntValidator_bottom(QIntValidatorH handle)
{
	return (int) ((QIntValidator *)handle)->bottom();
}

int QIntValidator_top(QIntValidatorH handle)
{
	return (int) ((QIntValidator *)handle)->top();
}

QDoubleValidatorH QDoubleValidator_create(QObjectH parent)
{
	return (QDoubleValidatorH) new QDoubleValidator((QObject*)parent);
}

void QDoubleValidator_destroy(QDoubleValidatorH handle)
{
	delete (QDoubleValidator *)handle;
}

QDoubleValidatorH QDoubleValidator_create2(double bottom, double top, int decimals, QObjectH parent)
{
	return (QDoubleValidatorH) new QDoubleValidator(bottom, top, decimals, (QObject*)parent);
}

QValidator::State QDoubleValidator_validate(QDoubleValidatorH handle, PWideString p1, int* p2)
{
	QString t_p1;
	copyPWideStringToQString(p1, t_p1);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QDoubleValidator *)handle)->validate(t_p1, *(int*)p2);
	copyQStringToPWideString(t_p1, p1);
	return t_retval;
}

void QDoubleValidator_setRange(QDoubleValidatorH handle, double bottom, double top, int decimals)
{
	((QDoubleValidator *)handle)->setRange(bottom, top, decimals);
}

void QDoubleValidator_setBottom(QDoubleValidatorH handle, double p1)
{
	((QDoubleValidator *)handle)->setBottom(p1);
}

void QDoubleValidator_setTop(QDoubleValidatorH handle, double p1)
{
	((QDoubleValidator *)handle)->setTop(p1);
}

void QDoubleValidator_setDecimals(QDoubleValidatorH handle, int p1)
{
	((QDoubleValidator *)handle)->setDecimals(p1);
}

void QDoubleValidator_setNotation(QDoubleValidatorH handle, QDoubleValidator::Notation p1)
{
	((QDoubleValidator *)handle)->setNotation(p1);
}

double QDoubleValidator_bottom(QDoubleValidatorH handle)
{
	return (double) ((QDoubleValidator *)handle)->bottom();
}

double QDoubleValidator_top(QDoubleValidatorH handle)
{
	return (double) ((QDoubleValidator *)handle)->top();
}

int QDoubleValidator_decimals(QDoubleValidatorH handle)
{
	return (int) ((QDoubleValidator *)handle)->decimals();
}

QDoubleValidator::Notation QDoubleValidator_notation(QDoubleValidatorH handle)
{
	return (QDoubleValidator::Notation) ((QDoubleValidator *)handle)->notation();
}

QRegExpValidatorH QRegExpValidator_create(QObjectH parent)
{
	return (QRegExpValidatorH) new QRegExpValidator((QObject*)parent);
}

void QRegExpValidator_destroy(QRegExpValidatorH handle)
{
	delete (QRegExpValidator *)handle;
}

QRegExpValidatorH QRegExpValidator_create2(const QRegExpH rx, QObjectH parent)
{
	return (QRegExpValidatorH) new QRegExpValidator(*(const QRegExp*)rx, (QObject*)parent);
}

QValidator::State QRegExpValidator_validate(QRegExpValidatorH handle, PWideString input, int* pos)
{
	QString t_input;
	copyPWideStringToQString(input, t_input);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QRegExpValidator *)handle)->validate(t_input, *(int*)pos);
	copyQStringToPWideString(t_input, input);
	return t_retval;
}

void QRegExpValidator_setRegExp(QRegExpValidatorH handle, const QRegExpH rx)
{
	((QRegExpValidator *)handle)->setRegExp(*(const QRegExp*)rx);
}

const QRegExpH QRegExpValidator_regExp(QRegExpValidatorH handle)
{
	return (const QRegExpH) &((QRegExpValidator *)handle)->regExp();
}

==> libqt4pas_2.5.orig.tar.gz: splitbuild-qt4pas-V2.5_Qt4.5.3/src/qvalidator_c.cpp <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#include "qvalidator_c.h"

void QValidator_setLocale(QValidatorH handle, const QLocaleH locale)
{
	((QValidator *)handle)->setLocale(*(const QLocale*)locale);
}

void QValidator_locale(QValidatorH handle, QLocaleH retval)
{
	*(QLocale *)retval = ((QValidator *)handle)->locale();
}

QValidator::State QValidator_validate(QValidatorH handle, PWideString AnonParam1, int* AnonParam2)
{
	QString t_AnonParam1;
	copyPWideStringToQString(AnonParam1, t_AnonParam1);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QValidator *)handle)->validate(t_AnonParam1, *(int*)AnonParam2);
	copyQStringToPWideString(t_AnonParam1, AnonParam1);
	return t_retval;
}

void QValidator_fixup(QValidatorH handle, PWideString AnonParam1)
{
	QString t_AnonParam1;
	copyPWideStringToQString(AnonParam1, t_AnonParam1);
	((QValidator *)handle)->fixup(t_AnonParam1);
	copyQStringToPWideString(t_AnonParam1, AnonParam1);
}

QIntValidatorH QIntValidator_create(QObjectH parent)
{
	return (QIntValidatorH) new QIntValidator((QObject*)parent);
}

void QIntValidator_destroy(QIntValidatorH handle)
{
	delete (QIntValidator *)handle;
}

QIntValidatorH QIntValidator_create2(int bottom, int top, QObjectH parent)
{
	return (QIntValidatorH) new QIntValidator(bottom, top, (QObject*)parent);
}

QValidator::State QIntValidator_validate(QIntValidatorH handle, PWideString AnonParam1, int* AnonParam2)
{
	QString t_AnonParam1;
	copyPWideStringToQString(AnonParam1, t_AnonParam1);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QIntValidator *)handle)->validate(t_AnonParam1, *(int*)AnonParam2);
	copyQStringToPWideString(t_AnonParam1, AnonParam1);
	return t_retval;
}

void QIntValidator_setBottom(QIntValidatorH handle, int AnonParam1)
{
	((QIntValidator *)handle)->setBottom(AnonParam1);
}

void QIntValidator_setTop(QIntValidatorH handle, int AnonParam1)
{
	((QIntValidator *)handle)->setTop(AnonParam1);
}

void QIntValidator_setRange(QIntValidatorH handle, int bottom, int top)
{
	((QIntValidator *)handle)->setRange(bottom, top);
}

int QIntValidator_bottom(QIntValidatorH handle)
{
	return (int) ((QIntValidator *)handle)->bottom();
}

int QIntValidator_top(QIntValidatorH handle)
{
	return (int) ((QIntValidator *)handle)->top();
}

QDoubleValidatorH QDoubleValidator_create(QObjectH parent)
{
	return (QDoubleValidatorH) new QDoubleValidator((QObject*)parent);
}

void QDoubleValidator_destroy(QDoubleValidatorH handle)
{
	delete (QDoubleValidator *)handle;
}

QDoubleValidatorH QDoubleValidator_create2(double bottom, double top, int decimals, QObjectH parent)
{
	return (QDoubleValidatorH) new QDoubleValidator(bottom, top, decimals, (QObject*)parent);
}

QValidator::State QDoubleValidator_validate(QDoubleValidatorH handle, PWideString AnonParam1, int* AnonParam2)
{
	QString t_AnonParam1;
	copyPWideStringToQString(AnonParam1, t_AnonParam1);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QDoubleValidator *)handle)->validate(t_AnonParam1, *(int*)AnonParam2);
	copyQStringToPWideString(t_AnonParam1, AnonParam1);
	return t_retval;
}

void QDoubleValidator_setRange(QDoubleValidatorH handle, double bottom, double top, int decimals)
{
	((QDoubleValidator *)handle)->setRange(bottom, top, decimals);
}

void QDoubleValidator_setBottom(QDoubleValidatorH handle, double AnonParam1)
{
	((QDoubleValidator *)handle)->setBottom(AnonParam1);
}

void QDoubleValidator_setTop(QDoubleValidatorH handle, double AnonParam1)
{
	((QDoubleValidator *)handle)->setTop(AnonParam1);
}

void QDoubleValidator_setDecimals(QDoubleValidatorH handle, int AnonParam1)
{
	((QDoubleValidator *)handle)->setDecimals(AnonParam1);
}

void QDoubleValidator_setNotation(QDoubleValidatorH handle, QDoubleValidator::Notation AnonParam1)
{
	((QDoubleValidator *)handle)->setNotation(AnonParam1);
}

double QDoubleValidator_bottom(QDoubleValidatorH handle)
{
	return (double) ((QDoubleValidator *)handle)->bottom();
}

double QDoubleValidator_top(QDoubleValidatorH handle)
{
	return (double) ((QDoubleValidator *)handle)->top();
}

int QDoubleValidator_decimals(QDoubleValidatorH handle)
{
	return (int) ((QDoubleValidator *)handle)->decimals();
}

QDoubleValidator::Notation QDoubleValidator_notation(QDoubleValidatorH handle)
{
	return (QDoubleValidator::Notation) ((QDoubleValidator *)handle)->notation();
}

QRegExpValidatorH QRegExpValidator_create(QObjectH parent)
{
	return (QRegExpValidatorH) new QRegExpValidator((QObject*)parent);
}

void QRegExpValidator_destroy(QRegExpValidatorH handle)
{
	delete (QRegExpValidator *)handle;
}

QRegExpValidatorH QRegExpValidator_create2(const QRegExpH rx, QObjectH parent)
{
	return (QRegExpValidatorH) new QRegExpValidator(*(const QRegExp*)rx, (QObject*)parent);
}

QValidator::State QRegExpValidator_validate(QRegExpValidatorH handle, PWideString input, int* pos)
{
	QString t_input;
	copyPWideStringToQString(input, t_input);
	QValidator::State t_retval;
	t_retval = (QValidator::State) ((QRegExpValidator *)handle)->validate(t_input, *(int*)pos);
	copyQStringToPWideString(t_input, input);
	return t_retval;
}

void QRegExpValidator_setRegExp(QRegExpValidatorH handle, const QRegExpH rx)
{
	((QRegExpValidator *)handle)->setRegExp(*(const QRegExp*)rx);
}

const QRegExpH QRegExpValidator_regExp(QRegExpValidatorH handle)
{
	return (const QRegExpH) &((QRegExpValidator *)handle)->regExp();
}
